@@ -22,14 +22,20 @@ class NetboxStorageRootView(APIRootView):
 
 
 class DriveViewSet(NetBoxModelViewSet):
-    queryset = Drive.objects.all()
+    queryset = Drive.objects.all().prefetch_related("windowsvolumes")
     serializer_class = DriveSerializer
     filterset_class = DriveFilter
 
+    #@action(detail=True, methods=["get"])
+    #def drive(self, request, pk=None):
+    #    drives = Drive.objects.filter(drive__id=pk)
+    #    serializer = DriveSerializer(drives, many=True, context={"request": request})
+    #    return Response(serializer.data)
+
     @action(detail=True, methods=["get"])
-    def drive(self, request, pk=None):
-        drives = Drive.objects.filter(drive__id=pk)
-        serializer = DriveSerializer(drives, many=True, context={"request": request})
+    def windowsvolumes(self, request, pk=None):
+        windowsvolumes = WindowsVolume.objects.filter(drives__id=pk)
+        serializer = WindowsVolumeSerializer(windowsvolumes, many=True, context={"request": request})
         return Response(serializer.data)
 
 
@@ -58,12 +64,20 @@ class LinuxVolumeViewSet(NetBoxModelViewSet):
 
 
 class WindowsVolumeViewSet(NetBoxModelViewSet):
-    queryset = WindowsVolume.objects.all()
+    queryset = WindowsVolume.objects.all().prefetch_related("drives")
     serializer_class = WindowsVolumeSerializer
     filterset_class = WindowsVolumeFilter
 
+    #@action(detail=True, methods=["get"])
+    #def windowsvolume(self, request, pk=None):
+    #    windowsvolume = WindowsVolume.objects.filter(windowsvolume__id=pk)
+    #    serializer = WindowsVolumeSerializer(windowsvolume, many=True, context={"request": request})
+    #    return Response(serializer.data)
+
     @action(detail=True, methods=["get"])
-    def windowsvolume(self, request, pk=None):
-        windowsvolume = WindowsVolume.objects.filter(windowsvolume__id=pk)
-        serializer = WindowsVolumeSerializer(windowsvolume, many=True, context={"request": request})
+    def drives(self, request, pk=None):
+        drives = Drive.objects.filter(windowsvolumes__id=pk)
+        serializer = DriveSerializer(
+            drives, many=True, context={"request": request}
+        )
         return Response(serializer.data)
