@@ -20,6 +20,12 @@ class FilesystemForm(NetBoxModelForm):
     filesystem = CharField(
         required=True,
         label="Filesystem Name",
+        help_text="The name of the filesystem e.g. ext4, NTFS",
+    )
+    description = CharField(
+        required=False,
+        label="Description",
+        help_text="Short Description e.g. NTFS is a Filesystem for Windows",
     )
 
     class Meta:
