@@ -72,7 +72,7 @@ class Migration(migrations.Migration):
                 ("vg_name", models.CharField(max_length=255)),
                 ("lv_name", models.CharField(max_length=255)),
                 ("path", models.CharField(max_length=255)),
-                ('fs',
+                ("fs",
                  models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE, related_name='fs_linux',
                                    to='netbox_storage.filesystem')),
                 ("description", models.CharField(max_length=255)),
@@ -105,10 +105,40 @@ class Migration(migrations.Migration):
                         blank=True, related_name="drives", to="netbox_storage.drive"
                     ),
                 ),
+                ('virtual_machine',
+                 models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE,
+                                   related_name='drive_volume', to='virtualization.virtualmachine')),
                 ("description", models.CharField(max_length=255)),
             ],
             options={
                 "ordering": ("drive_name", "id"),
             },
         ),
+        migrations.CreateModel(
+            name="LinuxVolumeDrive",
+            fields=[
+                ("created", models.DateTimeField(auto_now_add=True, null=True)),
+                ("last_updated", models.DateTimeField(auto_now=True, null=True)),
+                (
+                    "custom_field_data",
+                    models.JSONField(
+                        blank=True,
+                        default=dict,
+                        encoder=utilities.json.CustomFieldJSONEncoder
+                    ),
+                ),
+                ("id", models.BigAutoField(primary_key=True, serialize=False)),
+                ("allocation", models.PositiveIntegerField()),
+                ("drive",
+                 models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE, related_name='drive',
+                                   to='netbox_storage.drive')),
+                ("linuxvolume",
+                 models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE, related_name='linuxvolume',
+                                   to='netbox_storage.linuxvolume')),
+                ("description", models.CharField(max_length=255)),
+            ],
+            options={
+                "ordering": ("drive", "linuxvolume"),
+            },
+        ),
     ]
