@@ -2,7 +2,6 @@ from django.db import models
 from django.urls import reverse
 
 from netbox.models import NetBoxModel
-from netbox.search import SearchIndex, register_search
 
 
 class Drive(NetBoxModel):
@@ -27,7 +26,7 @@ class Drive(NetBoxModel):
         blank=True,
     )
 
-    clone_fields = ["size", "cluster", "virtual_machine", "description"]
+    clone_fields = ["size", "identifier", "cluster", "virtual_machine", "description"]
 
     prerequisite_models = (
         'virtualization.Cluster',
@@ -43,13 +42,20 @@ class Drive(NetBoxModel):
     def get_absolute_url(self):
         return reverse("plugins:netbox_storage:drive", kwargs={"pk": self.pk})
 
-    # this is not needed if small_image is created at set_image
     def save(self, *args, **kwargs):
-        number_of_hard_drives = Drive.objects.filter(virtual_machine=self.virtual_machine).order_by("created").count()
+        is_already_implemented = Drive.objects.filter(id=self.pk).count()
+        if is_already_implemented == 0:
+            number_of_hard_drives = Drive.objects.filter(virtual_machine=self.virtual_machine).order_by("created")\
+                .count()
+
+            self.identifier = f"Hard Drive {number_of_hard_drives + 1}"
 
-        self.identifier = f"Hard Drive {number_of_hard_drives + 1}"
         super(Drive, self).save(*args, **kwargs)
 
+    @property
+    def docs_url(self):
+        return f'https://confluence.ti8m.ch/docs/models/drive/'
+
 
 class Filesystem(NetBoxModel):
     filesystem = models.CharField(
@@ -102,6 +108,10 @@ class LinuxVolume(NetBoxModel):
             "description",
         ]
 
+    prerequisite_models = (
+        'dcim.platform'
+    )
+
     def get_absolute_url(self):
         return reverse("plugins:netbox_storage:linuxvolume", kwargs={"pk": self.pk})
 
@@ -122,11 +132,6 @@ class WindowsVolume(NetBoxModel):
         related_name="fs_windows",
         verbose_name="Filesystem",
     )
-    drives = models.ManyToManyField(
-        Drive,
-        related_name="drives",
-        verbose_name="Drives",
-    )
     description = models.CharField(
         max_length=255,
         blank=True,
@@ -135,10 +140,13 @@ class WindowsVolume(NetBoxModel):
     clone_fields = [
             "drive_name",
             "fs",
-            "drives",
             "description",
         ]
 
+    prerequisite_models = (
+        'dcim.platform'
+    )
+
     def get_absolute_url(self):
         return reverse("plugins:netbox_storage:windowsvolume", kwargs={"pk": self.pk})
 
@@ -147,3 +155,39 @@ class WindowsVolume(NetBoxModel):
 
     class Meta:
         ordering = ("drive_name", "fs")
+
+
+class LinuxVolumeDrive(NetBoxModel):
+    drive = models.ForeignKey(
+        Drive,
+        on_delete=models.CASCADE,
+        related_name='drive',
+    )
+    linuxvolume = models.ForeignKey(
+        LinuxVolume,
+        on_delete=models.CASCADE,
+        related_name='linuxvolume',
+    )
+    allocation = models.PositiveIntegerField(
+        verbose_name="Allocation"
+    )
+    description = models.CharField(
+        max_length=255,
+        blank=True,
+    )
+
+    clone_fields = [
+            "drive",
+            "linuxvolume",
+            "allocation",
+            "description",
+        ]
+
+    def get_absolute_url(self):
+        return reverse("plugins:netbox_storage:linuxvolumedrive", kwargs={"pk": self.pk})
+
+    def __str__(self):
+        return f"{self.drive}-{self.linuxvolume}"
+
+    class Meta:
+        ordering = ("drive", "linuxvolume")
