@@ -3,15 +3,13 @@ import django_tables2 as tables
 from netbox.tables import (
     NetBoxTable,
     ToggleColumn,
-    ActionsColumn,
 )
 
 from netbox_storage.models import WindowsVolume
 
 
-class WindowsVolumeBaseTable(NetBoxTable):
-    """Base class for tables displaying WindowsVolume"""
-
+class WindowsVolumeTable(NetBoxTable):
+    """Table for displaying WindowsVolume objects."""
     fs = tables.Column(
         linkify=True,
     )
@@ -19,10 +17,9 @@ class WindowsVolumeBaseTable(NetBoxTable):
         linkify=True,
         verbose_name="Drive Name"
     )
-
-
-class WindowsVolumeTable(WindowsVolumeBaseTable):
-    """Table for displaying WindowsVolume objects."""
+    virtual_machine = tables.Column(
+        linkify=True
+    )
 
     pk = ToggleColumn()
 
@@ -33,29 +30,12 @@ class WindowsVolumeTable(WindowsVolumeBaseTable):
             "drive_name",
             "fs",
             "drives",
+            "virtual_machine",
             "description",
         )
         default_columns = (
             "drive_name",
             "fs",
-            "description"
+            "drives",
+            "virtual_machine"
         )
-
-
-class RelatedWindowsVolumeTable(WindowsVolumeBaseTable):
-    actions = ActionsColumn(actions=())
-
-    class Meta(NetBoxTable.Meta):
-        model = WindowsVolume
-        fields = (
-            "pk",
-            "drive_name",
-            "fs",
-            "description",
-        )
-        default_columns = (
-            "drive_name",
-            "fs",
-            "description"
-        )
-
